.. title:: Home

.. toctree::
   :maxdepth: 2

.. currentmodule:: skrub

.. toctree::
   :hidden:

   install
   documentation
   reference/index
   auto_examples/index
   CHANGES
   development
   CONTRIBUTING
